@@ -245,6 +245,12 @@ Output format:
 
 
 """
+
+__updated__ = '74.220820104710'
+Version = f"1.6.{__updated__}"
+
+
+
 from typing import Union
 import logging
 import logging.config
@@ -1054,15 +1060,15 @@ class _LogP():
 
         # Überschreibe die Übersetungen
         if translation is not None and isinstance(translation, dict):
-            for k in self._InitTranslation.keys():                   # pylint: disable=C0201
+            for k, InitItem in self._InitTranslation.items():
                 try:
                     w = translation[k]
                     if not isinstance(w, str):
-                        self._Translation[k] = self._InitTranslation[k]
+                        self._Translation[k] = InitItem
                     else:
                         self._Translation[k] = w
                 except KeyError:
-                    self._Translation[k] = self._InitTranslation[k]
+                    self._Translation[k] = InitItem
 
 
         if not NoReset:
