@@ -1,11 +1,18 @@
-import setuptools
+#!/usr/bin/env python3
+# vim: expandtab:ts=4:sw=4:noai
 
-with open("README_Argpass.md", "r") as fh:
+""" Setup Argpass """
+
+import setuptools
+from pcs_argpass.Param import Version
+
+with open("README_Argpass.md", "r", encoding='utf-8') as fh:
     long_description = fh.read()
 
 setuptools.setup(
     name="pcs_argpass",
-    version="0.10.8",
+    # version="0.10.9",
+    version=Version,
     python_requires='>=3.6',
     author="Rainer Pietsch",
     author_email="r.pietsch@pcs-at.com",
